diff --git a/services/web/test/frontend/features/share-project-modal/components/share-project-modal.test.js b/services/web/test/frontend/features/share-project-modal/components/share-project-modal.test.js
index 14fc599835..c0a42ca189 100644
--- a/services/web/test/frontend/features/share-project-modal/components/share-project-modal.test.js
+++ b/services/web/test/frontend/features/share-project-modal/components/share-project-modal.test.js
@@ -175,7 +175,7 @@ describe('', function () {
await screen.findByRole('button', { name: 'Make Private' })
})
- it('hides actions from non-admins', async function () {
+ it('hides actions from non-project-owners', async function () {
const invites = [
{
_id: 'invited-author',
@@ -184,7 +184,7 @@ describe('', function () {
},
]
// render as admin: actions should be present
render(
', function () {
await screen.findByRole('button', { name: 'Turn off link sharing' })
await screen.findByRole('button', { name: 'Resend' })
// render as non-admin (non-owner), link sharing on: actions should be missing and message should be present
render(
', function () {
.null
expect(screen.queryByRole('button', { name: 'Resend' })).to.be.null
// render as non-admin (non-owner), link sharing off: actions should be missing and message should be present
render(
@@ -184,7 +184,7 @@ describe('', function () {
},
]
- // render as admin: actions should be present
+ // render as project owner: actions should be present
render(
', function () {
@@ -184,7 +184,7 @@ describe('', function () {
await screen.findByRole('button', { name: 'Turn off link sharing' })
await screen.findByRole('button', { name: 'Resend' })
- // render as non-admin (non-owner), link sharing on: actions should be missing and message should be present
+ // render as non-project-owner, link sharing on: actions should be missing and message should be present
render(
', function () {
@@ -184,7 +184,7 @@ describe('', function () {
.null
expect(screen.queryByRole('button', { name: 'Resend' })).to.be.null
- // render as non-admin (non-owner), link sharing off: actions should be missing and message should be present
+ // render as non-project-owner, link sharing off: actions should be missing and message should be present
render(